==> haskell-text-builder-0.6.5-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-builder
version: 0.6.5
id: text-builder-0.6.5-KICXNwtO5vO8xIbkV02tkP
key: text-builder-0.6.5-KICXNwtO5vO8xIbkV02tkP
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/text-builder
synopsis: An efficient strict text builder
category: Text
abi: 614c81381745a8a246d6c1da87f4aaa8
exposed: True
exposed-modules:
    Text.Builder
hidden-modules: Text.Builder.UTF16 Text.Builder.Prelude
import-dirs: /usr/lib/ghc-8.6.3/site-local/text-builder-0.6.5
library-dirs: /usr/lib/ghc-8.6.3/site-local/text-builder-0.6.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/text-builder-0.6.5
hs-libraries: HStext-builder-0.6.5-KICXNwtO5vO8xIbkV02tkP
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2 deferred-folds-0.9.10-Gt8uXZE7fq3KCL2z58lZES
    text-1.2.3.1 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-text-builder/html/text-builder.haddock
haddock-html: /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-builder
version: 0.6.5
id: text-builder-0.6.5-L4rNcsUMtyYFvFWVn5nNHZ
key: text-builder-0.6.5-L4rNcsUMtyYFvFWVn5nNHZ
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/text-builder
synopsis: An efficient strict text builder
category: Text
abi: d3f13505ef7bca9dd50a179b2de822d7
exposed: True
exposed-modules:
    Text.Builder
hidden-modules: Text.Builder.UTF16 Text.Builder.Prelude
import-dirs: /usr/lib/ghc-8.6.3/site-local/text-builder-0.6.5
library-dirs: /usr/lib/ghc-8.6.3/site-local/text-builder-0.6.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/text-builder-0.6.5
hs-libraries: HStext-builder-0.6.5-L4rNcsUMtyYFvFWVn5nNHZ
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2 deferred-folds-0.9.10-BZzaeg5NQlw6g2feXfgsDL
    text-1.2.3.1 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-text-builder/html/text-builder.haddock
haddock-html: /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
